<?php
/**
 * VW Portfolio Theme Customizer
 *
 * @package VW Portfolio
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_portfolio_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_portfolio_custom_controls' );

function vw_portfolio_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_portfolio_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-portfolio' ),
	    'description' => __( 'Description of what this panel does.', 'vw-portfolio' ),
	) );

	$wp_customize->add_section( 'vw_portfolio_left_right', array(
    	'title'      => __( 'General Settings', 'vw-portfolio' ),
		'priority'   => 30,
		'panel' => 'vw_portfolio_panel_id'
	) );

	$wp_customize->add_setting('vw_portfolio_width_option',array(
        'default' => __('Full Width','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Portfolio_Image_Radio_Control($wp_customize, 'vw_portfolio_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-portfolio'),
        'description' => __('Here you can change the width layout of Website.','vw-portfolio'),
        'section' => 'vw_portfolio_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_portfolio_theme_options',array(
        'default' => __('Right Sidebar','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_portfolio_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-portfolio'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-portfolio'),
        'section' => 'vw_portfolio_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-portfolio'),
            'Right Sidebar' => __('Right Sidebar','vw-portfolio'),
            'One Column' => __('One Column','vw-portfolio'),
            'Three Columns' => __('Three Columns','vw-portfolio'),
            'Four Columns' => __('Four Columns','vw-portfolio'),
            'Grid Layout' => __('Grid Layout','vw-portfolio')
        ),
	));

	$wp_customize->add_setting('vw_portfolio_page_layout',array(
        'default' => __('One Column','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));
	$wp_customize->add_control('vw_portfolio_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-portfolio'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-portfolio'),
        'section' => 'vw_portfolio_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-portfolio'),
            'Right Sidebar' => __('Right Sidebar','vw-portfolio'),
            'One Column' => __('One Column','vw-portfolio')
        ),
	) );

	//search
	$wp_customize->add_setting( 'vw_portfolio_search_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_search_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Search','vw-portfolio' ),
          'section' => 'vw_portfolio_left_right'
    )));

	//Sticky Header
	$wp_customize->add_setting( 'vw_portfolio_sticky_header',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-portfolio' ),
        'section' => 'vw_portfolio_left_right'
    )));

    //Pre-Loader
	$wp_customize->add_setting( 'vw_portfolio_loader_enable',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-portfolio' ),
        'section' => 'vw_portfolio_left_right'
    )));

    $wp_customize->add_setting('vw_portfolio_loader_icon',array(
        'default' => __('Two Way','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));
	$wp_customize->add_control('vw_portfolio_loader_icon',array(
        'type' => 'select',
        'label' => __('Pre-Loader Type','vw-portfolio'),
        'section' => 'vw_portfolio_left_right',
        'choices' => array(
            'Two Way' => __('Two Way','vw-portfolio'),
            'Dots' => __('Dots','vw-portfolio'),
            'Rotate' => __('Rotate','vw-portfolio')
        ),
	) );
    
	//Slider
	$wp_customize->add_section( 'vw_portfolio_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-portfolio' ),
		'priority'   => null,
		'panel' => 'vw_portfolio_panel_id'
	) );

	$wp_customize->add_setting( 'vw_portfolio_slider_hide_show',
       array(
          'default' => 1,
          'transport' => 'refresh',
          'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_slider_hide_show',
       array(
          'label' => esc_html__( 'Show / Hide Slider','vw-portfolio' ),
          'section' => 'vw_portfolio_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_portfolio_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_portfolio_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_portfolio_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-portfolio' ),
			'description' => __('Slider image size (1500 x 600)','vw-portfolio'),
			'section'  => 'vw_portfolio_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('vw_portfolio_slider_content_option',array(
        'default' => __('Left','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Portfolio_Image_Radio_Control($wp_customize, 'vw_portfolio_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-portfolio'),
        'section' => 'vw_portfolio_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_portfolio_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_portfolio_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-portfolio' ),
		'section'     => 'vw_portfolio_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_portfolio_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_portfolio_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_portfolio_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-portfolio' ),
	'section'     => 'vw_portfolio_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_portfolio_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-portfolio'),
      '0.1' =>  esc_attr('0.1','vw-portfolio'),
      '0.2' =>  esc_attr('0.2','vw-portfolio'),
      '0.3' =>  esc_attr('0.3','vw-portfolio'),
      '0.4' =>  esc_attr('0.4','vw-portfolio'),
      '0.5' =>  esc_attr('0.5','vw-portfolio'),
      '0.6' =>  esc_attr('0.6','vw-portfolio'),
      '0.7' =>  esc_attr('0.7','vw-portfolio'),
      '0.8' =>  esc_attr('0.8','vw-portfolio'),
      '0.9' =>  esc_attr('0.9','vw-portfolio')
	),
	));

	//Awesome Service
	$wp_customize->add_section( 'vw_portfolio_services_section' , array(
    	'title'      => __( 'Awesome Services', 'vw-portfolio' ),
		'priority'   => null,
		'panel' => 'vw_portfolio_panel_id'
	) );

	$wp_customize->add_setting('vw_portfolio_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_portfolio_section_title',array(
		'label'	=> __('Section Title','vw-portfolio'),
		'section'=> 'vw_portfolio_services_section',
		'setting'=> 'vw_portfolio_section_title',
		'type'=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$catpst[]='Select';
	foreach($categories as $category){
	if($i==0){
	$default = $category->slug;
	$i++;
	}
	$catpst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('vw_portfolio_awesome_services',array(
		'default'	=> 'select',
		'sanitize_callback' => 'vw_portfolio_sanitize_choices',
	));
	$wp_customize->add_control('vw_portfolio_awesome_services',array(
		'type'    => 'select',
		'choices' => $catpst,
		'label' => __('Select Category to display Services','vw-portfolio'),
		'description' => __('Image size (120 x 120)','vw-portfolio'),
		'section' => 'vw_portfolio_services_section',
	));

	//Services excerpt
	$wp_customize->add_setting( 'vw_portfolio_services_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_portfolio_services_excerpt_number', array(
		'label'       => esc_html__( 'Services Excerpt length','vw-portfolio' ),
		'section'     => 'vw_portfolio_services_section',
		'type'        => 'range',
		'settings'    => 'vw_portfolio_services_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_portfolio_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-portfolio'),
		'panel' => 'vw_portfolio_panel_id',
	));	

	$wp_customize->add_setting( 'vw_portfolio_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-portfolio' ),
        'section' => 'vw_portfolio_blog_post'
    )));

    $wp_customize->add_setting( 'vw_portfolio_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_toggle_author',array(
		'label' => esc_html__( 'Author','vw-portfolio' ),
		'section' => 'vw_portfolio_blog_post'
    )));

    $wp_customize->add_setting( 'vw_portfolio_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-portfolio' ),
		'section' => 'vw_portfolio_blog_post'
    )));

    $wp_customize->add_setting( 'vw_portfolio_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_portfolio_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-portfolio' ),
		'section'     => 'vw_portfolio_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_portfolio_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_portfolio_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-portfolio' ),
		'priority' => null,
		'panel' => 'vw_portfolio_panel_id'
	) );

	$wp_customize->add_setting('vw_portfolio_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Portfolio_Content_Creation( $wp_customize, 'vw_portfolio_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-portfolio' ),
		),
		'section' => 'vw_portfolio_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-portfolio' ),
	) ) );
	
	//Footer Text
	$wp_customize->add_section('vw_portfolio_footer',array(
		'title'	=> __('Footer','vw-portfolio'),
		'description'=> __('This section will appear in the footer','vw-portfolio'),
		'panel' => 'vw_portfolio_panel_id',
	));	
	
	$wp_customize->add_setting('vw_portfolio_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_portfolio_footer_text',array(
		'label'	=> __('Copyright Text','vw-portfolio'),
		'section'=> 'vw_portfolio_footer',
		'setting'=> 'vw_portfolio_footer_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_portfolio_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_portfolio_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Portfolio_Toggle_Switch_Custom_Control( $wp_customize, 'vw_portfolio_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-portfolio' ),
      	'section' => 'vw_portfolio_footer'
    )));

	$wp_customize->add_setting('vw_portfolio_scroll_top_alignment',array(
        'default' => __('Right','vw-portfolio'),
        'sanitize_callback' => 'vw_portfolio_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Portfolio_Image_Radio_Control($wp_customize, 'vw_portfolio_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-portfolio'),
        'section' => 'vw_portfolio_footer',
        'settings' => 'vw_portfolio_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));	
}

add_action( 'customize_register', 'vw_portfolio_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Portfolio_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Portfolio_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Portfolio_Customize_Section_Pro($manager,'example_1',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Portfolio Pro', 'vw-portfolio' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-portfolio' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/wordpress-portfolio-theme/'),
		)));

		$manager->add_section(new VW_Portfolio_Customize_Section_Pro($manager,'example_2',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-portfolio' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-portfolio' ),
			'pro_url'  => admin_url('themes.php?page=vw_portfolio_guide'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-portfolio-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-portfolio-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Portfolio_Customize::get_instance();